@@ -1,10 +1,5 @@
 package ArrayData::Test::Spec::Basic;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-18'; # DATE
-our $DIST = 'ArrayData'; # DIST
-our $VERSION = '0.2.3'; # VERSION
-
 use strict;
 use warnings;
 
@@ -12,6 +7,11 @@ use Role::Tiny::With;
 
 with 'ArrayDataRole::Spec::Basic';
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-26'; # DATE
+our $DIST = 'ArrayData'; # DIST
+our $VERSION = '0.2.4'; # VERSION
+
 my $elems = [
     1,
     2,
@@ -71,7 +71,7 @@ sub has_item_at_pos {
 
 1;
 
-# ABSTRACT: A test table data
+# ABSTRACT: A test array data
 
 __END__
 
@@ -81,11 +81,11 @@ __END__
 
 =head1 NAME
 
-ArrayData::Test::Spec::Basic - A test table data
+ArrayData::Test::Spec::Basic - A test array data
 
 =head1 VERSION
 
-This document describes version 0.2.3 of ArrayData::Test::Spec::Basic (from Perl distribution ArrayData), released on 2021-05-18.
+This document describes version 0.2.4 of ArrayData::Test::Spec::Basic (from Perl distribution ArrayData), released on 2021-09-26.
 
 =for Pod::Coverage ^(.+)$
 
@@ -97,23 +97,40 @@ Please visit the project's homepage at L<https://metacpan.org/release/ArrayData>
 
 Source repository is at L<https://github.com/perlancar/perl-ArrayData>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-ArrayData/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ArrayData>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
