@@ -1,13 +1,16 @@
 package ArrayDataRole::Spec::Basic;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-18'; # DATE
-our $DIST = 'ArrayData'; # DIST
-our $VERSION = '0.2.3'; # VERSION
+use strict;
+use warnings;
 
 use Role::Tiny;
 use Role::Tiny::With;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-26'; # DATE
+our $DIST = 'ArrayData'; # DIST
+our $VERSION = '0.2.4'; # VERSION
+
 # constructor
 requires 'new';
 
@@ -63,7 +66,7 @@ ArrayDataRole::Spec::Basic - Required methods for all ArrayData::* modules
 
 =head1 VERSION
 
-This document describes version 0.2.3 of ArrayDataRole::Spec::Basic (from Perl distribution ArrayData), released on 2021-05-18.
+This document describes version 0.2.4 of ArrayDataRole::Spec::Basic (from Perl distribution ArrayData), released on 2021-09-26.
 
 =head1 DESCRIPTION
 
@@ -135,14 +138,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/ArrayData>
 
 Source repository is at L<https://github.com/perlancar/perl-ArrayData>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-ArrayData/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Role::TinyCommons::Iterator::Resettable>
@@ -153,11 +148,36 @@ L<Role::TinyCommons::Collection::GetItemByPos>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by perlancar@cpan.org.
+This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ArrayData>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
